%bcond_with bootstrap

%if %{with bootstrap}
%bcond_with tests
%bcond_with doc
%else
%bcond_without tests
%bcond_without doc
%endif

%global srcname pip
%global bashcompdir %(pkg-config --variable=completionsdir bash-completion 2>/dev/null)

Summary:        The Python package installer
Name:           python-%{srcname}
Version:        23.3.1
Release:        5%{?dist}
License:        MIT and Python and ASL 2.0 and BSD and ISC and LGPLv2 and MPLv2.0 and (ASL 2.0 or BSD)
URL:            https://pip.pypa.io/
Source0:        https://github.com/pypa/pip/archive/%{version}/%{srcname}-%{version}.tar.gz

Patch3001:      remove-existing-dist-only-if-path-conflicts.patch
Patch3002:      dummy-certifi.patch
Patch3003:      nowarn-pip._internal.main.patch
Patch3004:      no-version-warning.patch

BuildRequires:  python3-devel python3-setuptools python3-rpm-generators bash-completion
BuildRequires:  python3-wheel python3-attrs ca-certificates

# generate it with:
# %%{_rpmconfigdir}/pythonbundles.py --namespace 'python3dist' src/pip/_vendor/vendor.txt
%global bundled() %{expand:
Provides: bundled(python3dist(cachecontrol)) = 0.13.1
Provides: bundled(python3dist(certifi)) = 2023.7.22
Provides: bundled(python3dist(chardet)) = 5.1
Provides: bundled(python3dist(colorama)) = 0.4.6
Provides: bundled(python3dist(distlib)) = 0.3.6
Provides: bundled(python3dist(distro)) = 1.8
Provides: bundled(python3dist(idna)) = 3.4
Provides: bundled(python3dist(msgpack)) = 1.0.5
Provides: bundled(python3dist(packaging)) = 21.3
Provides: bundled(python3dist(platformdirs)) = 3.8.1
Provides: bundled(python3dist(pygments)) = 2.15.1
Provides: bundled(python3dist(pyparsing)) = 3.1
Provides: bundled(python3dist(pyproject-hooks)) = 1
Provides: bundled(python3dist(requests)) = 2.31
Provides: bundled(python3dist(resolvelib)) = 1.0.1
Provides: bundled(python3dist(rich)) = 13.4.2
Provides: bundled(python3dist(setuptools)) = 68
Provides: bundled(python3dist(six)) = 1.16
Provides: bundled(python3dist(tenacity)) = 8.2.2
Provides: bundled(python3dist(truststore)) = 0.8
Provides: bundled(python3dist(tomli)) = 2.0.1
Provides: bundled(python3dist(typing-extensions)) = 4.7.1
Provides: bundled(python3dist(urllib3)) = 1.26.17
Provides: bundled(python3dist(webencodings)) = 0.5.1
}

# for doc
%if %{with doc}
BuildRequires:  python3-sphinx
%endif

%if %{with tests}
BuildRequires:  python-setuptools-wheel python-wheel-wheel python3-cryptography
BuildRequires:  python3-pytest python3-scripttest
BuildRequires:  python3-virtualenv python3-pyyaml python3-tomli-w
BuildRequires:  /usr/bin/git
%endif
BuildArch:      noarch

%description
Pip is the package installer for Python. You can use pip to install 
packages from the Python Package Index and other indexes.

%package -n python3-%{srcname}
Summary:        The Python package installer

Requires:       ca-certificates
Requires:       python3-libs >= 3.10.0-2
Recommends:     python3-setuptools
Recommends:     (libcrypt.so.1()(64bit) if python3(x86-64))
Provides:       pip = %{version}-%{release}
%{bundled}

%description -n python3-%{srcname}
Pip is the package installer for Python. You can use pip to install
packages from the Python Package Index and other indexes.

%package -n     %{python_wheel_pkg_prefix}-%{srcname}-wheel
Summary:        The pip wheel
Requires:       ca-certificates
Recommends:     (libcrypt.so.1()(64bit) if python3(x86-64))
%{bundled}

%description -n %{python_wheel_pkg_prefix}-%{srcname}-wheel
A Python wheel of pip to use with venv.

%prep
%autosetup -p1 -n %{srcname}-%{version}

rm -fv src/pip/_vendor/certifi/*.pem
sed -i '/"myst_parser",/d' docs/html/conf.py
sed -i '/"sphinx_copybutton",/d' docs/html/conf.py
sed -i '/"sphinx_inline_tabs",/d' docs/html/conf.py
sed -i '/"sphinxcontrib.towncrier",/d' docs/html/conf.py
ln -s %{python_wheel_dir} tests/data/common_wheels
grep -lr "^#\!/usr/bin/env python" src/pip/_vendor/ | xargs sed -i "1d"

find src/pip/_vendor -name "*.exe" -type f -exec rm -fv {} \;
sed -i '/\.exe/d' setup.py

%build
%py3_build_wheel

%if %{with doc}
export PYTHONPATH=./src/
sphinx-build-3 -b man -c docs/html docs/man docs/build/man
%endif

%install
%{python3} dist/%{srcname}-%{version}-py3-none-any.whl/pip install \
    --root %{buildroot} \
    --no-deps \
    --disable-pip-version-check \
    --progress-bar off \
    --verbose \
    --ignore-installed \
    --no-warn-script-location \
    --no-index \
    --no-cache-dir \
    --find-links dist \
    'pip==%{version}'

%if %{with doc}
pushd docs/build/man
install -d %{buildroot}%{_mandir}/man1
for MAN in *1; do
install -pm0644 $MAN %{buildroot}%{_mandir}/man1/$MAN
for pip in "pip3" "pip-3" "pip%{python3_version}" "pip-%{python3_version}"; do
echo ".so $MAN" > %{buildroot}%{_mandir}/man1/${MAN/pip/$pip}
done
done
popd
%endif

mkdir -p %{buildroot}%{bashcompdir}
PYTHONPATH=%{buildroot}%{python3_sitelib} \
    %{buildroot}%{_bindir}/pip completion --bash \
    > %{buildroot}%{bashcompdir}/pip3

sed -i -e "s/^\\(complete.*\\) pip\$/\\1 pip pip{,-}{3,%{python3_version}}/" \
    -e s/_pip_completion/_pip3_completion/ \
    %{buildroot}%{bashcompdir}/pip3

ln -s ./pip%{python3_version} %{buildroot}%{_bindir}/pip-%{python3_version}
ln -s ./pip-%{python3_version} %{buildroot}%{_bindir}/pip-3

echo rpm > %{buildroot}%{python3_sitelib}/pip-%{version}.dist-info/INSTALLER
rm %{buildroot}%{python3_sitelib}/pip-%{version}.dist-info/RECORD

mkdir -p %{buildroot}%{python_wheel_dir}
install -p dist/%{srcname}-%{version}-py3-none-any.whl -t %{buildroot}%{python_wheel_dir}

%if %{with tests}
%check
%{_rpmconfigdir}/pythonbundles.py src/pip/_vendor/vendor.txt --compare-with '%{bundled 3}'

pytest_k='not completion'

# disable some tests due to some pkgs are not supported
rm -f tests/conftest.py
%pytest -m 'not network' -k "$(echo $pytest_k)" \
    --ignore=tests/unit/test_collector.py \
    --ignore=tests/unit/test_finder.py \
    --ignore=tests/unit/test_network_cache.py \
    --ignore=tests/unit/test_network_lazy_wheel.py \
    --ignore=tests/unit/test_operations_prepare.py \
    --ignore=tests/unit/test_pep517.py \
    --ignore=tests/unit/test_req.py \
    --ignore=tests/unit/test_req_file.py \
    --ignore=tests/unit/test_resolution_legacy_resolver.py \
    --ignore=tests/unit/test_utils_unpacking.py \
    --ignore=tests/unit/test_utils_wheel.py \
    --ignore=tests/unit/test_wheel.py \
    --ignore=tests/unit/resolution_resolvelib/test_provider.py \
    --ignore=tests/unit/resolution_resolvelib/test_requirement.py \
    --ignore=tests/unit/resolution_resolvelib/test_resolver.py \
    --ignore=tests/unit/test_base_command.py \
    --ignore=tests/unit/test_cache.py \
    --ignore=tests/unit/test_compat.py \
    --ignore=tests/unit/test_direct_url_helpers.py \
    --ignore=tests/unit/test_locations.py \
    --ignore=tests/unit/test_network_session.py \
    --ignore=tests/unit/test_req_install.py \
    --ignore=tests/unit/test_req_uninstall.py \
    --ignore=tests/unit/test_self_check_outdated.py \
    --ignore=tests/unit/test_utils.py \
    --ignore=tests/unit/test_utils_virtualenv.py \
    --ignore=tests/unit/test_wheel_builder.py \
    --ignore=tests/functional --ignore=tests/lib/test_lib.py
%endif

%files -n python3-%{srcname}
%license %{python3_sitelib}/pip-%{version}.dist-info/LICENSE.txt
%doc README.rst
%{python3_sitelib}/pip*
%dir %{bashcompdir}
%{bashcompdir}/pip3
%{_bindir}/pip
%{_bindir}/pip3
%{_bindir}/pip-3
%{_bindir}/pip%{python3_version}
%{_bindir}/pip-%{python3_version}
%if %{with doc}
%{_mandir}/man1/pip.*
%{_mandir}/man1/pip-*.*
%{_mandir}/man1/pip3.*
%{_mandir}/man1/pip3-*.*
%endif

%files -n %{python_wheel_pkg_prefix}-%{srcname}-wheel
%license LICENSE.txt
%dir %{python_wheel_dir}/
%{python_wheel_dir}/%{srcname}-%{version}-py3-none-any.whl

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 23.3.1-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Mon Sep 2 2024 Shuo Wang <abushwang@tencent.com> - 23.3.1-4
- remove some unused BuildRequires

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 23.3.1-3
- Rebuilt for loongarch release

* Thu May 30 2024 Shuo Wang <abushwang@tencent.com> - 23.3.1-2
- enable %check

* Wed Jan 10 2024 Upgrade Robot <upbot@opencloudos.org> - 23.3.1-1
- Upgrade to version 23.3.1

* Tue Sep 19 2023 Shuo Wang <abushwang@tencent.com> - 22.3.1-2
- Rebuilt for python 3.11

* Tue Sep 19 2023 Shuo Wang <abushwang@tencent.com> - 22.3.1-1
- update to 22.3.1

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 22.1.1-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 22.1.1-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 22.1.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 22.1.1-2
- Rebuilt for OpenCloudOS Stream 23

* Thu May 26 2022 Xiaojie Chen <jackxjchen@tencent.com> 22.1.1-1
- Initial build
